==> guile-1.6.0.tar.gz: guile-1.6.0/libguile/scmsigs.h <==
/* classes: h_files */

#ifndef SCMSIGSH
#define SCMSIGSH
/*	Copyright (C) 1995,1996,1997,1998, 2000 Free Software Foundation, Inc.
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this software; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 59 Temple Place, Suite 330,
 * Boston, MA 02111-1307 USA
 *
 * As a special exception, the Free Software Foundation gives permission
 * for additional uses of the text contained in its release of GUILE.
 *
 * The exception is that, if you link the GUILE library with other files
 * to produce an executable, this does not by itself cause the
 * resulting executable to be covered by the GNU General Public License.
 * Your use of that executable is in no way restricted on account of
 * linking the GUILE library code into it.
 *
 * This exception does not however invalidate any other reasons why
 * the executable file might be covered by the GNU General Public License.
 *
 * This exception applies only to the code released by the
 * Free Software Foundation under the name GUILE.  If you copy
 * code from other Free Software Foundation releases into a copy of
 * GUILE, as the General Public License permits, the exception does
 * not apply to the code that you add in this way.  To avoid misleading
 * anyone as to the status of such modified files, you must delete
 * this exception notice from them.
 *
 * If you write modifications of your own for GUILE, it is your choice
 * whether to permit this exception to apply to your modifications.
 * If you do not wish that, delete this exception notice.  */

#include "libguile/__scm.h"



extern SCM scm_sigaction (SCM signum, SCM handler, SCM flags);
extern SCM scm_restore_signals (void);
extern SCM scm_alarm (SCM i);
extern SCM scm_setitimer (SCM which_timer,
                          SCM interval_seconds, SCM interval_microseconds,
                          SCM value_seconds, SCM value_microseconds);
extern SCM scm_getitimer (SCM which_timer);
extern SCM scm_pause (void);
extern SCM scm_sleep (SCM i);
extern SCM scm_usleep (SCM i);
extern SCM scm_raise (SCM sig);
extern void scm_init_scmsigs (void);

#endif  /* SCMSIGSH */

/*
  Local Variables:
  c-file-style: "gnu"
  End:
*/

==> guile-1.6.8.tar.gz: guile-1.6.8/libguile/scmsigs.h <==
/* classes: h_files */

#ifndef SCMSIGSH
#define SCMSIGSH
/*	Copyright (C) 1995,1996,1997,1998, 2000 Free Software Foundation, Inc.
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this software; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301 USA
 *
 * As a special exception, the Free Software Foundation gives permission
 * for additional uses of the text contained in its release of GUILE.
 *
 * The exception is that, if you link the GUILE library with other files
 * to produce an executable, this does not by itself cause the
 * resulting executable to be covered by the GNU General Public License.
 * Your use of that executable is in no way restricted on account of
 * linking the GUILE library code into it.
 *
 * This exception does not however invalidate any other reasons why
 * the executable file might be covered by the GNU General Public License.
 *
 * This exception applies only to the code released by the
 * Free Software Foundation under the name GUILE.  If you copy
 * code from other Free Software Foundation releases into a copy of
 * GUILE, as the General Public License permits, the exception does
 * not apply to the code that you add in this way.  To avoid misleading
 * anyone as to the status of such modified files, you must delete
 * this exception notice from them.
 *
 * If you write modifications of your own for GUILE, it is your choice
 * whether to permit this exception to apply to your modifications.
 * If you do not wish that, delete this exception notice.  */

#include "libguile/__scm.h"



extern SCM scm_sigaction (SCM signum, SCM handler, SCM flags);
extern SCM scm_restore_signals (void);
extern SCM scm_alarm (SCM i);
extern SCM scm_setitimer (SCM which_timer,
                          SCM interval_seconds, SCM interval_microseconds,
                          SCM value_seconds, SCM value_microseconds);
extern SCM scm_getitimer (SCM which_timer);
extern SCM scm_pause (void);
extern SCM scm_sleep (SCM i);
extern SCM scm_usleep (SCM i);
extern SCM scm_raise (SCM sig);
extern void scm_init_scmsigs (void);

#endif  /* SCMSIGSH */

/*
  Local Variables:
  c-file-style: "gnu"
  End:
*/
